@@ -1,4 +1,5 @@
 import ast
+import sys
 
 from .expression_printer import ExpressionPrinter
 
@@ -111,7 +112,7 @@ class ModulePrinter(ExpressionPrinter):
         self.code += '='
 
         # Yield nodes that are the sole node on the right hand side of an assignment do not need parens
-        if  isinstance(node.value, ast.Yield):
+        if isinstance(node.value, ast.Yield):
             self._yield_expr(node.value)
         elif hasattr(ast, 'YieldFrom') and isinstance(node.value, ast.YieldFrom):
             self._yield_expr(node.value)
@@ -160,7 +161,14 @@ class ModulePrinter(ExpressionPrinter):
 
         self.token_break()
         self.code += 'return'
-        if node.value is not None:
+        if isinstance(node.value, ast.Tuple):
+            if sys.version_info < (3, 8) and hasattr(ast, 'Starred') and [n for n in node.value.elts if isinstance(n, ast.Starred)]:
+                self.code += '('
+                self._testlist(node.value)
+                self.code += ')'
+            else:
+                self._testlist(node.value)
+        elif node.value is not None:
             self._testlist(node.value)
         self.end_statement()
 
@@ -484,7 +492,7 @@ class ModulePrinter(ExpressionPrinter):
 
         for d in node.decorator_list:
             self.code += '@'
-            self.visit(d)
+            self._expression(d)
             self.newline()
 
         if is_async:
@@ -513,7 +521,7 @@ class ModulePrinter(ExpressionPrinter):
 
         for d in node.decorator_list:
             self.code += '@'
-            self.visit(d)
+            self._expression(d)
             self.newline()
 
         first = True
@@ -574,12 +582,6 @@ class ModulePrinter(ExpressionPrinter):
         assert isinstance(node, ast.AsyncFunctionDef)
         self.visit_FunctionDef(node, is_async=True)
 
-    def visit_Await(self, node):
-        assert isinstance(node, ast.Await)
-        self.token_break()
-        self.code += 'await'
-        self._rhs(node.value, node)
-
     def visit_AsyncFor(self, node):
         assert isinstance(node, ast.AsyncFor)
         self.visit_For(node, is_async=True)
